@@ -301,7 +301,7 @@ namespace SourceGit
                     return await clipboard.GetTextAsync();
                 }
             }
-            return default;
+            return null;
         }
 
         public static string Text(string key, params object[] args)
@@ -323,8 +323,7 @@ namespace SourceGit
             icon.Height = 12;
             icon.Stretch = Stretch.Uniform;
 
-            var geo = Current?.FindResource(key) as StreamGeometry;
-            if (geo != null)
+            if (Current?.FindResource(key) is StreamGeometry geo)
                 icon.Data = geo;
 
             return icon;
@@ -522,7 +521,7 @@ namespace SourceGit
         private bool TryLaunchAsCoreEditor(IClassicDesktopStyleApplicationLifetime desktop)
         {
             var args = desktop.Args;
-            if (args == null || args.Length <= 1 || !args[0].Equals("--core-editor", StringComparison.Ordinal))
+            if (args is not { Length: > 1 } || !args[0].Equals("--core-editor", StringComparison.Ordinal))
                 return false;
 
             var file = args[1];
@@ -532,8 +531,8 @@ namespace SourceGit
                 return true;
             }
 
-            var editor = new Views.StandaloneCommitMessageEditor();
-            editor.SetFile(file);
+            var editor = new Views.CommitMessageEditor();
+            editor.AsStandalone(file);
             desktop.MainWindow = editor;
             return true;
         }
@@ -682,8 +681,7 @@ namespace SourceGit
                 }
 
                 var name = sb.ToString();
-                var idx = name.IndexOf('#');
-                if (idx >= 0)
+                if (name.Contains('#', StringComparison.Ordinal))
                 {
                     if (!name.Equals("fonts:Inter#Inter", StringComparison.Ordinal) &&
                         !name.Equals("fonts:SourceGit#JetBrains Mono", StringComparison.Ordinal))
