@@ -15,6 +15,17 @@ namespace SourceGit.ViewModels
             set;
         }
 
+        public bool IsRecurseSubmoduleVisible
+        {
+            get => _repo.Submodules.Count > 0;
+        }
+
+        public bool RecurseSubmodules
+        {
+            get => _repo.Settings.UpdateSubmodulesOnCheckoutBranch;
+            set => _repo.Settings.UpdateSubmodulesOnCheckoutBranch = value;
+        }
+
         public Checkout(Repository repo, string branch)
         {
             _repo = repo;
@@ -30,19 +41,22 @@ namespace SourceGit.ViewModels
             var log = _repo.CreateLog($"Checkout '{Branch}'");
             Use(log);
 
+            var updateSubmodules = IsRecurseSubmoduleVisible && RecurseSubmodules;
             return Task.Run(() =>
             {
-                var changes = new Commands.CountLocalChangesWithoutUntracked(_repo.FullPath).Result();
+                var succ = false;
                 var needPopStash = false;
-                if (changes > 0)
+
+                if (DiscardLocalChanges)
                 {
-                    if (DiscardLocalChanges)
+                    succ = new Commands.Checkout(_repo.FullPath).Use(log).Branch(Branch, true);
+                }
+                else
+                {
+                    var changes = new Commands.CountLocalChangesWithoutUntracked(_repo.FullPath).Result();
+                    if (changes > 0)
                     {
-                        Commands.Discard.All(_repo.FullPath, false, log);
-                    }
-                    else
-                    {
-                        var succ = new Commands.Stash(_repo.FullPath).Use(log).Push("CHECKOUT_AUTO_STASH");
+                        succ = new Commands.Stash(_repo.FullPath).Use(log).Push("CHECKOUT_AUTO_STASH");
                         if (!succ)
                         {
                             log.Complete();
@@ -52,16 +66,29 @@ namespace SourceGit.ViewModels
 
                         needPopStash = true;
                     }
+
+                    succ = new Commands.Checkout(_repo.FullPath).Use(log).Branch(Branch, false);
                 }
 
-                var rs = new Commands.Checkout(_repo.FullPath).Use(log).Branch(Branch);
-                if (needPopStash)
-                    rs = new Commands.Stash(_repo.FullPath).Use(log).Pop("stash@{0}");
+                if (succ)
+                {
+                    if (updateSubmodules)
+                    {
+                        var submodules = new Commands.QueryUpdatableSubmodules(_repo.FullPath).Result();
+                        if (submodules.Count > 0)
+                            new Commands.Submodule(_repo.FullPath).Use(log).Update(submodules, true, true);
+                    }
+
+                    if (needPopStash)
+                        new Commands.Stash(_repo.FullPath).Use(log).Pop("stash@{0}");
+                }
 
                 log.Complete();
 
                 CallUIThread(() =>
                 {
+                    ProgressDescription = "Waiting for branch updated...";
+
                     var b = _repo.Branches.Find(x => x.IsLocal && x.Name == Branch);
                     if (b != null && _repo.HistoriesFilterMode == Models.FilterMode.Included)
                         _repo.SetBranchFilterMode(b, Models.FilterMode.Included, true, false);
@@ -70,7 +97,8 @@ namespace SourceGit.ViewModels
                     _repo.SetWatcherEnabled(true);
                 });
 
-                return rs;
+                Task.Delay(400).Wait();
+                return succ;
             });
         }
 
