@@ -65,17 +65,14 @@ namespace SourceGit.ViewModels
                 var repos = ActiveWorkspace.Repositories.ToArray();
                 foreach (var repo in repos)
                 {
-                    var node = pref.FindNode(repo);
-                    if (node == null)
-                    {
-                        node = new RepositoryNode()
+                    var node = pref.FindNode(repo) ??
+                        new RepositoryNode
                         {
                             Id = repo,
                             Name = Path.GetFileName(repo),
                             Bookmark = 0,
                             IsRepository = true,
                         };
-                    }
 
                     OpenRepositoryInTab(node, null);
                 }
@@ -184,17 +181,14 @@ namespace SourceGit.ViewModels
             var repos = to.Repositories.ToArray();
             foreach (var repo in repos)
             {
-                var node = pref.FindNode(repo);
-                if (node == null)
-                {
-                    node = new RepositoryNode()
+                var node = pref.FindNode(repo) ??
+                    new RepositoryNode
                     {
                         Id = repo,
                         Name = Path.GetFileName(repo),
                         Bookmark = 0,
                         IsRepository = true,
                     };
-                }
 
                 OpenRepositoryInTab(node, null);
             }
@@ -290,23 +284,15 @@ namespace SourceGit.ViewModels
                 return;
             }
 
-            if (page == null)
-                page = _activePage;
+            page ??= _activePage;
 
             var removeIdx = Pages.IndexOf(page);
             var activeIdx = Pages.IndexOf(_activePage);
             if (removeIdx == activeIdx)
-            {
                 ActivePage = Pages[removeIdx > 0 ? removeIdx - 1 : removeIdx + 1];
-                CloseRepositoryInTab(page);
-                Pages.RemoveAt(removeIdx);
-            }
-            else
-            {
-                CloseRepositoryInTab(page);
-                Pages.RemoveAt(removeIdx);
-            }
 
+            CloseRepositoryInTab(page);
+            Pages.RemoveAt(removeIdx);
             GC.Collect();
         }
 
