@@ -64,7 +64,6 @@ namespace SourceGit.ViewModels
                     }
 
                     Preferences.Instance.AutoRemoveInvalidNode();
-                    Preferences.Instance.SortNodes(Preferences.Instance.RepositoryNodes);
                     Preferences.Instance.Save();
 
                     Welcome.Instance.Refresh();
@@ -128,14 +127,14 @@ namespace SourceGit.ViewModels
 
         private RepositoryNode FindOrCreateGroupRecursive(List<RepositoryNode> collection, string path)
         {
-            var idx = path.IndexOf('/');
-            if (idx < 0)
-                return FindOrCreateGroup(collection, path);
+            RepositoryNode node = null;
+            foreach (var name in path.Split('/'))
+            {
+                node = FindOrCreateGroup(collection, name);
+                collection = node.SubNodes;
+            }
 
-            var name = path.Substring(0, idx);
-            var tail = path.Substring(idx + 1);
-            var parent = FindOrCreateGroup(collection, name);
-            return FindOrCreateGroupRecursive(parent.SubNodes, tail);
+            return node;
         }
 
         private RepositoryNode FindOrCreateGroup(List<RepositoryNode> collection, string name)
@@ -154,8 +153,8 @@ namespace SourceGit.ViewModels
                 IsExpanded = true,
             };
             collection.Add(added);
-            Preferences.Instance.SortNodes(collection);
 
+            Preferences.Instance.SortNodes(collection);
             return added;
         }
 
