@@ -581,7 +581,7 @@ namespace SourceGit.ViewModels
             DoCommit(false, true);
         }
 
-        public ContextMenu CreateContextMenuForUnstagedChanges()
+        public ContextMenu CreateContextMenuForUnstagedChanges(string selectedSingleFolder)
         {
             if (_selectedUnstaged == null || _selectedUnstaged.Count == 0)
                 return null;
@@ -761,52 +761,76 @@ namespace SourceGit.ViewModels
                     var hasExtra = false;
                     if (change.WorkTree == Models.ChangeState.Untracked)
                     {
-                        var isRooted = change.Path.IndexOf('/', StringComparison.Ordinal) <= 0;
                         var addToIgnore = new MenuItem();
                         addToIgnore.Header = App.Text("WorkingCopy.AddToGitIgnore");
                         addToIgnore.Icon = App.CreateMenuIcon("Icons.GitIgnore");
 
-                        var singleFile = new MenuItem();
-                        singleFile.Header = App.Text("WorkingCopy.AddToGitIgnore.SingleFile");
-                        singleFile.Click += (_, e) =>
+                        if (!string.IsNullOrEmpty(selectedSingleFolder))
                         {
-                            Commands.GitIgnore.Add(_repo.FullPath, change.Path);
-                            e.Handled = true;
-                        };
-                        addToIgnore.Items.Add(singleFile);
-
-                        var byParentFolder = new MenuItem();
-                        byParentFolder.Header = App.Text("WorkingCopy.AddToGitIgnore.InSameFolder");
-                        byParentFolder.IsVisible = !isRooted;
-                        byParentFolder.Click += (_, e) =>
-                        {
-                            var dir = Path.GetDirectoryName(change.Path)!.Replace('\\', '/').TrimEnd('/');
-                            Commands.GitIgnore.Add(_repo.FullPath, dir + "/");
-                            e.Handled = true;
-                        };
-                        addToIgnore.Items.Add(byParentFolder);
-
-                        if (!string.IsNullOrEmpty(extension))
-                        {
-                            var byExtension = new MenuItem();
-                            byExtension.Header = App.Text("WorkingCopy.AddToGitIgnore.Extension", extension);
-                            byExtension.Click += (_, e) =>
+                            var ignoreFolder = new MenuItem();
+                            ignoreFolder.Header = App.Text("WorkingCopy.AddToGitIgnore.InFolder");
+                            ignoreFolder.Click += (_, e) =>
                             {
-                                Commands.GitIgnore.Add(_repo.FullPath, $"*{extension}");
+                                Commands.GitIgnore.Add(_repo.FullPath, $"{selectedSingleFolder}/");
                                 e.Handled = true;
                             };
-                            addToIgnore.Items.Add(byExtension);
-
-                            var byExtensionInSameFolder = new MenuItem();
-                            byExtensionInSameFolder.Header = App.Text("WorkingCopy.AddToGitIgnore.ExtensionInSameFolder", extension);
-                            byExtensionInSameFolder.IsVisible = !isRooted;
-                            byExtensionInSameFolder.Click += (_, e) =>
+                            addToIgnore.Items.Add(ignoreFolder);
+                        }
+                        else
+                        {
+                            var isRooted = change.Path.IndexOf('/', StringComparison.Ordinal) <= 0;
+                            var singleFile = new MenuItem();
+                            singleFile.Header = App.Text("WorkingCopy.AddToGitIgnore.SingleFile");
+                            singleFile.Click += (_, e) =>
                             {
-                                var dir = Path.GetDirectoryName(change.Path)!.Replace('\\', '/').TrimEnd('/');
-                                Commands.GitIgnore.Add(_repo.FullPath, $"{dir}/*{extension}");
+                                Commands.GitIgnore.Add(_repo.FullPath, change.Path);
                                 e.Handled = true;
                             };
-                            addToIgnore.Items.Add(byExtensionInSameFolder);
+                            addToIgnore.Items.Add(singleFile);
+
+                            if (!string.IsNullOrEmpty(extension))
+                            {
+                                var byExtension = new MenuItem();
+                                byExtension.Header = App.Text("WorkingCopy.AddToGitIgnore.Extension", extension);
+                                byExtension.Click += (_, e) =>
+                                {
+                                    Commands.GitIgnore.Add(_repo.FullPath, $"*{extension}");
+                                    e.Handled = true;
+                                };
+                                addToIgnore.Items.Add(byExtension);
+
+                                var byExtensionInSameFolder = new MenuItem();
+                                byExtensionInSameFolder.Header = App.Text("WorkingCopy.AddToGitIgnore.ExtensionInSameFolder", extension);
+                                byExtensionInSameFolder.IsVisible = !isRooted;
+                                byExtensionInSameFolder.Click += (_, e) =>
+                                {
+                                    var dir = Path.GetDirectoryName(change.Path)!.Replace('\\', '/').TrimEnd('/');
+                                    Commands.GitIgnore.Add(_repo.FullPath, $"{dir}/*{extension}");
+                                    e.Handled = true;
+                                };
+                                addToIgnore.Items.Add(byExtensionInSameFolder);
+                            }
+                        }
+
+                        menu.Items.Add(addToIgnore);
+                        hasExtra = true;
+                    }
+                    else if (!string.IsNullOrEmpty(selectedSingleFolder))
+                    {
+                        var addToIgnore = new MenuItem();
+                        addToIgnore.Header = App.Text("WorkingCopy.AddToGitIgnore");
+                        addToIgnore.Icon = App.CreateMenuIcon("Icons.GitIgnore");
+
+                        if (!string.IsNullOrEmpty(selectedSingleFolder))
+                        {
+                            var ignoreFolder = new MenuItem();
+                            ignoreFolder.Header = App.Text("WorkingCopy.AddToGitIgnore.InFolder");
+                            ignoreFolder.Click += (_, e) =>
+                            {
+                                Commands.GitIgnore.Add(_repo.FullPath, $"{selectedSingleFolder}/");
+                                e.Handled = true;
+                            };
+                            addToIgnore.Items.Add(ignoreFolder);
                         }
 
                         menu.Items.Add(addToIgnore);
@@ -1028,6 +1052,22 @@ namespace SourceGit.ViewModels
                     return menu;
                 }
 
+                if (!string.IsNullOrEmpty(selectedSingleFolder))
+                {
+                    var dir = Path.Combine(_repo.FullPath, selectedSingleFolder);
+                    var explore = new MenuItem();
+                    explore.Header = App.Text("RevealFile");
+                    explore.Icon = App.CreateMenuIcon("Icons.Explore");
+                    explore.IsEnabled = Directory.Exists(dir);
+                    explore.Click += (_, e) =>
+                    {
+                        Native.OS.OpenInFileManager(dir, true);
+                        e.Handled = true;
+                    };
+                    menu.Items.Add(explore);
+                    menu.Items.Add(new MenuItem() { Header = "-" });
+                }
+
                 var stage = new MenuItem();
                 stage.Header = App.Text("FileCM.StageMulti", _selectedUnstaged.Count);
                 stage.Icon = App.CreateMenuIcon("Icons.File.Add");
@@ -1086,12 +1126,31 @@ namespace SourceGit.ViewModels
                 menu.Items.Add(discard);
                 menu.Items.Add(stash);
                 menu.Items.Add(patch);
+
+                if (!string.IsNullOrEmpty(selectedSingleFolder))
+                {
+                    var ignoreFolder = new MenuItem();
+                    ignoreFolder.Header = App.Text("WorkingCopy.AddToGitIgnore.InFolder");
+                    ignoreFolder.Click += (_, e) =>
+                    {
+                        Commands.GitIgnore.Add(_repo.FullPath, $"{selectedSingleFolder}/");
+                        e.Handled = true;
+                    };
+
+                    var addToIgnore = new MenuItem();
+                    addToIgnore.Header = App.Text("WorkingCopy.AddToGitIgnore");
+                    addToIgnore.Icon = App.CreateMenuIcon("Icons.GitIgnore");
+                    addToIgnore.Items.Add(ignoreFolder);
+
+                    menu.Items.Add(new MenuItem() { Header = "-" });
+                    menu.Items.Add(addToIgnore);
+                }
             }
 
             return menu;
         }
 
-        public ContextMenu CreateContextMenuForStagedChanges()
+        public ContextMenu CreateContextMenuForStagedChanges(string selectedSingleFolder)
         {
             if (_selectedStaged == null || _selectedStaged.Count == 0)
                 return null;
@@ -1340,6 +1399,23 @@ namespace SourceGit.ViewModels
             }
             else
             {
+                if (!string.IsNullOrEmpty(selectedSingleFolder))
+                {
+                    var dir = Path.Combine(_repo.FullPath, selectedSingleFolder);
+                    var explore = new MenuItem();
+                    explore.IsEnabled = Directory.Exists(dir);
+                    explore.Header = App.Text("RevealFile");
+                    explore.Icon = App.CreateMenuIcon("Icons.Explore");
+                    explore.Click += (_, e) =>
+                    {
+                        Native.OS.OpenInFileManager(dir, true);
+                        e.Handled = true;
+                    };
+
+                    menu.Items.Add(explore);
+                    menu.Items.Add(new MenuItem() { Header = "-" });
+                }
+
                 var unstage = new MenuItem();
                 unstage.Header = App.Text("FileCM.UnstageMulti", _selectedStaged.Count);
                 unstage.Icon = App.CreateMenuIcon("Icons.File.Remove");
@@ -1778,16 +1854,11 @@ namespace SourceGit.ViewModels
             if (old.Count != cur.Count)
                 return true;
 
-            var oldMap = new Dictionary<string, Models.Change>();
-            foreach (var c in old)
-                oldMap.Add(c.Path, c);
-
-            foreach (var c in cur)
+            for (int idx = 0; idx < old.Count; idx++)
             {
-                if (!oldMap.TryGetValue(c.Path, out var o))
-                    return true;
-
-                if (o.Index != c.Index || o.WorkTree != c.WorkTree)
+                var o = old[idx];
+                var c = cur[idx];
+                if (o.Path != c.Path || o.Index != c.Index || o.WorkTree != c.WorkTree)
                     return true;
             }
 
