@@ -26,7 +26,7 @@ namespace SourceGit.Views
                 {
                     var folder = selected[0];
                     var folderPath = folder is { Path: { IsAbsoluteUri: true } path } ? path.LocalPath : folder?.Path.ToString();
-                    TxtLocation.Text = folderPath;
+                    TxtLocation.Text = folderPath.TrimEnd(['\\', '/']);
                 }
             }
             catch (Exception exception)
