@@ -51,7 +51,7 @@ namespace SourceGit.Views
                 options.DefaultExtension = ".patch";
                 options.FileTypeChoices = [new FilePickerFileType("Patch File") { Patterns = ["*.patch"] }];
 
-                var storageFile = await this.StorageProvider.SaveFilePickerAsync(options);
+                var storageFile = await StorageProvider.SaveFilePickerAsync(options);
                 if (storageFile != null)
                     await compare.SaveAsPatch(storageFile.Path.LocalPath);
 
@@ -76,5 +76,13 @@ namespace SourceGit.Views
                     ToolTip.SetTip(border, vm.GetCommitFullMessage(commit));
             }
         }
+
+        private async void OnOpenFileWithDefaultEditor(object sender, RoutedEventArgs e)
+        {
+            if (DataContext is ViewModels.FileHistories { ViewContent: ViewModels.FileHistoriesSingleRevision revision })
+                await revision.OpenWithDefaultEditor();
+
+            e.Handled = true;
+        }
     }
 }
