@@ -12,7 +12,7 @@ namespace SourceGit.Views
     public class CounterPresenter : Control
     {
         public static readonly StyledProperty<int> CountProperty =
-            AvaloniaProperty.Register<CounterPresenter, int>(nameof(Count), 0);
+            AvaloniaProperty.Register<CounterPresenter, int>(nameof(Count));
 
         public int Count
         {
@@ -208,7 +208,7 @@ namespace SourceGit.Views
 
         private void OnWorktreeListPropertyChanged(object _, AvaloniaPropertyChangedEventArgs e)
         {
-            if (e.Property == ListBox.ItemsSourceProperty || e.Property == ListBox.IsVisibleProperty)
+            if (e.Property == ItemsControl.ItemsSourceProperty || e.Property == IsVisibleProperty)
                 UpdateLeftSidebarLayout();
         }
 
@@ -221,7 +221,7 @@ namespace SourceGit.Views
         private void UpdateLeftSidebarLayout()
         {
             var vm = DataContext as ViewModels.Repository;
-            if (vm == null || vm.Settings == null)
+            if (vm?.Settings == null)
                 return;
 
             if (!IsLoaded)
