@@ -1,4 +1,5 @@
 using Avalonia.Controls;
+using Avalonia.Input;
 
 namespace SourceGit.Views
 {
@@ -23,6 +24,18 @@ namespace SourceGit.Views
                 layout.StashesLeftWidth = new GridLength(maxLeft, GridUnitType.Pixel);
         }
 
+        private void OnStashListKeyDown(object sender, KeyEventArgs e)
+        {
+            if (e.Key is not (Key.Delete or Key.Back))
+                return;
+
+            if (DataContext is not ViewModels.StashesPage vm)
+                return;
+
+            vm.Drop(vm.SelectedStash);
+            e.Handled = true;
+        }
+
         private void OnStashContextRequested(object sender, ContextRequestedEventArgs e)
         {
             if (DataContext is ViewModels.StashesPage vm && sender is Border border)
