@@ -348,16 +348,11 @@ namespace SourceGit.Views
             private ThemedTextDiffPresenter _presenter = null;
         }
 
-        public class LineStyleTransformer : DocumentColorizingTransformer
+        public class LineStyleTransformer(ThemedTextDiffPresenter presenter) : DocumentColorizingTransformer
         {
-            public LineStyleTransformer(ThemedTextDiffPresenter presenter)
-            {
-                _presenter = presenter;
-            }
-
             protected override void ColorizeLine(DocumentLine line)
             {
-                var lines = _presenter.GetLines();
+                var lines = presenter.GetLines();
                 var idx = line.LineNumber;
                 if (idx > lines.Count)
                     return;
@@ -367,13 +362,11 @@ namespace SourceGit.Views
                 {
                     ChangeLinePart(line.Offset, line.EndOffset, v =>
                     {
-                        v.TextRunProperties.SetForegroundBrush(_presenter.IndicatorForeground);
-                        v.TextRunProperties.SetTypeface(new Typeface(_presenter.FontFamily, FontStyle.Italic));
+                        v.TextRunProperties.SetForegroundBrush(presenter.IndicatorForeground);
+                        v.TextRunProperties.SetTypeface(new Typeface(presenter.FontFamily, FontStyle.Italic));
                     });
                 }
             }
-
-            private readonly ThemedTextDiffPresenter _presenter;
         }
 
         public static readonly StyledProperty<string> FileNameProperty =
@@ -765,12 +758,10 @@ namespace SourceGit.Views
             }
             else if (change.Property == BlockNavigationProperty)
             {
-                var oldValue = change.OldValue as ViewModels.BlockNavigation;
-                if (oldValue != null)
+                if (change.OldValue is ViewModels.BlockNavigation oldValue)
                     oldValue.PropertyChanged -= OnBlockNavigationPropertyChanged;
 
-                var newValue = change.NewValue as ViewModels.BlockNavigation;
-                if (newValue != null)
+                if (change.NewValue is ViewModels.BlockNavigation newValue)
                     newValue.PropertyChanged += OnBlockNavigationPropertyChanged;
 
                 TextArea?.TextView?.Redraw();
@@ -1251,8 +1242,7 @@ namespace SourceGit.Views
         {
             base.OnDataContextChanged(e);
 
-            var textDiff = DataContext as Models.TextDiff;
-            if (textDiff != null)
+            if (DataContext is Models.TextDiff textDiff)
             {
                 var builder = new StringBuilder();
                 foreach (var line in textDiff.Lines)
@@ -1410,8 +1400,7 @@ namespace SourceGit.Views
                 return;
             }
 
-            var textDiff = this.FindAncestorOfType<TextDiffView>()?.DataContext as Models.TextDiff;
-            if (textDiff != null)
+            if (this.FindAncestorOfType<TextDiffView>()?.DataContext is Models.TextDiff textDiff)
             {
                 var lineIdx = -1;
                 foreach (var line in view.VisualLines)
@@ -1537,7 +1526,7 @@ namespace SourceGit.Views
 
         private void DirectSyncScrollOffset()
         {
-            if (_scrollViewer is { } && DataContext is ViewModels.TwoSideTextDiff diff)
+            if (_scrollViewer is not null && DataContext is ViewModels.TwoSideTextDiff diff)
                 diff.SyncScrollOffset = _scrollViewer?.Offset ?? Vector.Zero;
         }
 
