@@ -31,9 +31,25 @@ namespace SourceGit.Views
 
         protected override void OnKeyDown(KeyEventArgs e)
         {
-            if (SelectedItem is ViewModels.RepositoryNode { IsRepository: false } node && e.KeyModifiers == KeyModifiers.None)
+            if (SelectedItem is ViewModels.RepositoryNode node && e.KeyModifiers == KeyModifiers.None)
             {
-                if ((node.IsExpanded && e.Key == Key.Left) || (!node.IsExpanded && e.Key == Key.Right))
+                if (e.Key is Key.Delete or Key.Back)
+                {
+                    node.Delete();
+                    e.Handled = true;
+                }
+                else if (node.IsRepository)
+                {
+                    if (e.Key == Key.Enter)
+                    {
+                        var parent = this.FindAncestorOfType<Launcher>();
+                        if (parent is { DataContext: ViewModels.Launcher launcher })
+                            launcher.OpenRepositoryInTab(node, null);
+
+                        e.Handled = true;
+                    }
+                }
+                else if ((node.IsExpanded && e.Key == Key.Left) || (!node.IsExpanded && e.Key == Key.Right) || e.Key == Key.Enter)
                 {
                     ViewModels.Welcome.Instance.ToggleNodeIsExpanded(node);
                     e.Handled = true;
@@ -92,25 +108,6 @@ namespace SourceGit.Views
             }
         }
 
-        private void OnTreeViewKeyDown(object _, KeyEventArgs e)
-        {
-            if (TreeContainer.SelectedItem is ViewModels.RepositoryNode node && e.Key == Key.Enter)
-            {
-                if (node.IsRepository)
-                {
-                    var parent = this.FindAncestorOfType<Launcher>();
-                    if (parent is { DataContext: ViewModels.Launcher launcher })
-                        launcher.OpenRepositoryInTab(node, null);
-                }
-                else
-                {
-                    ViewModels.Welcome.Instance.ToggleNodeIsExpanded(node);
-                }
-
-                e.Handled = true;
-            }
-        }
-
         private void OnTreeNodeContextRequested(object sender, ContextRequestedEventArgs e)
         {
             if (sender is Grid { DataContext: ViewModels.RepositoryNode node } grid)
@@ -218,16 +215,8 @@ namespace SourceGit.Views
                 if (to == null)
                     return;
 
-                if (to.IsRepository)
-                {
-                    e.DragEffects = DragDropEffects.None;
-                    e.Handled = true;
-                }
-                else
-                {
-                    e.DragEffects = DragDropEffects.Move;
-                    e.Handled = true;
-                }
+                e.DragEffects = to.IsRepository ? DragDropEffects.None : DragDropEffects.Move;
+                e.Handled = true;
             }
         }
 
